Struct Reloc
Source pub struct Reloc {
pub r_offset: u64,
pub r_addend: Option<i64>,
pub r_sym: usize,
pub r_type: u32,
}
A unified ELF relocation structure
The index into the corresponding symbol table - either dynamic or regular
Performs copy-assignment from
source.
Read moreSourceAvailable on crate feature alloc only.
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read moreSourceAvailable on crate feature alloc only.
Converts to this type from the input type.
SourceAvailable on crate feature alloc only.
Converts to this type from the input type.
SourceAvailable on crate feature alloc only.
Converts to this type from the input type.
SourceAvailable on crate feature alloc only.
Converts to this type from the input type.
SourceAvailable on crate feature alloc only.
Converts to this type from the input type.
SourceAvailable on crate feature alloc only.
Converts to this type from the input type.
SourceAvailable on crate feature alloc only.
Converts to this type from the input type.
SourceAvailable on crate feature alloc only.
Converts to this type from the input type.
SourceAvailable on crate feature alloc only.
Writes the relocation into bytes
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
SourceAvailable on crate feature alloc only.
SourceAvailable on crate feature alloc only.
SourceAvailable on crate feature alloc only.
Writes the relocation into bytes
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.