Struct goblin::mach::load_command::SubUmbrellaCommand [−][src]
#[repr(C)]pub struct SubUmbrellaCommand { pub cmd: u32, pub cmdsize: u32, pub sub_umbrella: LcStr, }
A dynamically linked shared library may be a sub_umbrella of an umbrella framework. If so it will be linked with “-sub_umbrella umbrella_name” where Where “umbrella_name” is the name of the sub_umbrella framework. When staticly linking when -twolevel_namespace is in effect a twolevel namespace umbrella framework will only cause its subframeworks and those frameworks listed as sub_umbrella frameworks to be implicited linked in. Any other dependent dynamic libraries will not be linked it when -twolevel_namespace is in effect. The primary library recorded by the static linker when resolving a symbol in these libraries will be the umbrella framework. Zero or more sub_umbrella frameworks may be use by an umbrella framework. The name of a sub_umbrella framework is recorded in the following structure.
Fields
cmd: u32LC_SUB_UMBRELLA
cmdsize: u32includes sub_umbrella string
sub_umbrella: LcStrthe sub_umbrella framework name