Cor20Header

Struct Cor20Header 

#[repr(C)]
pub struct Cor20Header { pub cb: u32, pub major_runtime_version: u16, pub minor_runtime_version: u16, pub metadata: DataDirectory, pub flags: u32, pub entry_point_token_or_rva: u32, pub resources: DataDirectory, pub strong_name_signature: DataDirectory, pub code_manager_table: DataDirectory, pub vtable_fixups: DataDirectory, pub export_address_table_jumps: DataDirectory, pub managed_native_header: DataDirectory, }
to .NET assemblies. This header is found in the COM descriptor directory of a PE file.

Fields

cb: u32

The size of this structure in bytes.

major_runtime_version: u16

Major runtime version number of the CLR.

minor_runtime_version: u16

Minor runtime version number of the CLR.

metadata: DataDirectory

The location and size of the metadata section, which contains metadata tables for the assembly, such as type definitions and member references.

flags: u32entry_point_token_or_rva: u32

Token or RVA of the entry point method for the assembly. For DLLs, this can be 0.

resources: DataDirectory

Data directory specifying resources in the assembly.

strong_name_signature: DataDirectory

Data directory containing the strong name signature of the assembly, if signed.

code_manager_table: DataDirectory

Data directory for the code manager table, reserved for internal use.

vtable_fixups: DataDirectory

Data directory for vtable fixups, used to fixup vtables in unmanaged code.

export_address_table_jumps: DataDirectory

Data directory for export address table jumps, which can be used for interop.

managed_native_header: DataDirectory

Data directory for a managed native header, reserved for future use.

Implementations

Source

impl Cor20Header

pub fn is_cb_correct(&self) -> bool

Returns true if Cor20Header::cb matches size of Cor20Header, otherwise false.

pub fn is_il_only(&self) -> bool

Whether the assembly contains only IL (Intermediate Language) code.

pub fn is_32bit_required(&self) -> bool

Whether the assembly requires a 32-bit environment to run.

pub fn is_il_library(&self) -> bool

Whether assembly is a library, not a standalone executable.

pub fn is_strong_name_signed(&self) -> bool

Whether assembly is signed with a strong name.

pub fn is_native_entrypoint(&self) -> bool

Whether the entry point for the assembly is a native method.

pub fn is_track_debug_data(&self) -> bool

Whether debug information is tracked for the assembly.

pub fn is_32bit_preferred(&self) -> bool

Whether the assembly prefers a 32-bit environment if available.