pub struct POGOInfoEntry<'a> {
pub rva: u32,
pub size: u32,
pub name: &'a [u8],
}Expand description
Represents the IMAGE_DEBUG_POGO_ENTRY structure
Fields
rva: u32The relative virtual address (RVA) of the PGO data.
size: u32The size of the PGO data block.
name: &'a [u8]The name of the function or data block associated with the PGO data as a byte slice.
This may contain a null-terminated string that represents the function or block name for which PGO optimization data is provided.