TeHeader

Struct TeHeader 

#[repr(C)]
pub struct TeHeader { pub signature: u16, pub machine: u16, pub number_of_sections: u8, pub subsystem: u8, pub stripped_size: u16, pub entry_point: u32, pub base_of_code: u32, pub image_base: u64, pub reloc_dir: DataDirectory, pub debug_dir: DataDirectory, }
The TE header is a reduced PE32/PE32+ header containing only fields required for execution in the Platform Initialization (PI) architecture. The TE header is described in this specification: https://uefi.org/specs/PI/1.8/V1_TE_Image.html#te-header

Fields

signature: u16

Te signature, always TE_MAGIC

machine: u16

The machine type

number_of_sections: u8

The number of sections

subsystem: u8

The subsystem

stripped_size: u16

the amount of bytes stripped from the header when converting from a PE32/PE32+ header to a TE header. Used to resolve addresses

entry_point: u32

The entry point of the binary

base_of_code: u32

The base of the code section

image_base: u64

The image base

reloc_dir: DataDirectory

The size and address of the relocation directory

debug_dir: DataDirectory

The size and address of the debug directory

Implementations

Source

impl TeHeader

pub fn parse(bytes: &[u8], offset: &mut usize) -> Result<Self>

Parse the TE header from the given bytes.

pub fn sections( &self, bytes: &[u8], offset: &mut usize, ) -> Result<Vec<SectionTable>>

Parse the sections from the TE header.