pub struct RichHeader<'a> {
pub key: u32,
pub data: &'a [u8],
pub padding_size: usize,
pub start_offset: u32,
pub end_offset: u32,
}Expand description
The Rich header is a undocumented header that is used to store information about the build environment.
The Rich Header first appeared in Visual Studio 6.0 and contains: a product identifier, build number, and the number of times it was used during the build process.
Fields
key: u32Key is 32-bit value used for XOR encrypt/decrypt fields
data: &'a [u8]The Rich header data with the padding.
padding_size: usizePadding bytes at the prologue of Self::data
start_offset: u32Start offset of the Rich header.
end_offset: u32End offset of the Rich header.
Implementations
Sourceimpl<'a> RichHeader<'a>
impl<'a> RichHeader<'a>
Sourcepub fn parse(bytes: &'a [u8]) -> Result<Option<Self>>
pub fn parse(bytes: &'a [u8]) -> Result<Option<Self>>
Parse the rich header from the given bytes.
To decode the Rich header,
- First locate the Rich marker and the subsequent 32-bit encryption key.
- Then, work backwards from the Rich marker, XORing the key with the stored 32-bit values until you decode the DanS marker.
Between these markers, you’ll find pairs of 32-bit values:
- the first indicates the Microsoft tool used, and
- the second shows the count of linked object files made with that tool.
- The upper 16 bits of the tool ID describe the tool type,
- while the lower 16 bits specify the tool’s build version.
Sourcepub fn metadatas(&self) -> RichMetadataIterator<'a> ⓘ
pub fn metadatas(&self) -> RichMetadataIterator<'a> ⓘ
Returns RichMetadataIterator iterator for RichMetadata