#[repr(C)]pub struct TeHeader {
pub signature: u16,
pub machine: u16,
pub number_of_sections: u8,
pub subsystem: u8,
pub stripped_size: u16,
pub entry_point: u32,
pub base_of_code: u32,
pub image_base: u64,
pub reloc_dir: DataDirectory,
pub debug_dir: DataDirectory,
}Expand description
The TE header is a reduced PE32/PE32+ header containing only fields required for execution in the Platform Initialization (PI) architecture. The TE header is described in this specification: https://uefi.org/specs/PI/1.8/V1_TE_Image.html#te-header
Fields
signature: u16Te signature, always TE_MAGIC
machine: u16The machine type
number_of_sections: u8The number of sections
subsystem: u8The subsystem
stripped_size: u16the amount of bytes stripped from the header when converting from a PE32/PE32+ header to a TE header. Used to resolve addresses
entry_point: u32The entry point of the binary
base_of_code: u32The base of the code section
image_base: u64The image base
reloc_dir: DataDirectoryThe size and address of the relocation directory
debug_dir: DataDirectoryThe size and address of the debug directory
Implementations